import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import MoleculeButtonGroup from '@s-ui/react-molecule-button-group';
import AtomButtom from '@schibstedspain/sui-atom-button';
import * as pagination from './helpers/pagination';
import { isValidPage, isValidTotalPages, isValidShowPages } from './customPropTypes';
var BASE_CLASS = 'sui-MoleculePagination';
var CLASS_PREV_BUTTON_ICON = 'sui-MoleculePagination-prevButtonIcon';
var CLASS_NEXT_BUTTON_ICON = 'sui-MoleculePagination-nextButtonIcon';

var PageButton = function PageButton(_ref) {
  var onSelectPage = _ref.onSelectPage,
      page = _ref.page,
      design = _ref.design,
      props = _objectWithoutPropertiesLoose(_ref, ["onSelectPage", "page", "design"]);

  var _onSelectPage = function _onSelectPage(e) {
    onSelectPage(e, {
      page: page
    });
  };

  return React.createElement(AtomButtom, Object.assign({
    onClick: _onSelectPage,
    design: design
  }, props));
};

var MoleculePagination = function MoleculePagination(_ref2) {
  var onSelectNext = _ref2.onSelectNext,
      onSelectPrev = _ref2.onSelectPrev,
      page = _ref2.page,
      totalPages = _ref2.totalPages,
      showPages = _ref2.showPages,
      prevButtonText = _ref2.prevButtonText,
      PrevButtonIcon = _ref2.prevButtonIcon,
      nextButtonText = _ref2.nextButtonText,
      NextButtonIcon = _ref2.nextButtonIcon,
      onSelectPage = _ref2.onSelectPage,
      compressed = _ref2.compressed,
      hideDisabled = _ref2.hideDisabled,
      selectedPageButtonDesign = _ref2.selectedPageButtonDesign,
      nonSelectedPageButtonDesign = _ref2.nonSelectedPageButtonDesign,
      prevButtonDesign = _ref2.prevButtonDesign,
      nextButtonDesign = _ref2.nextButtonDesign;
  var paramsPagination = {
    page: page,
    totalPages: totalPages,
    showPages: showPages
  };

  var handleClickNext = function handleClickNext(e) {
    var page = pagination.nextPage(paramsPagination);
    onSelectNext(e, {
      page: page
    });
  };

  var handleClickPrev = function handleClickPrev(e) {
    var page = pagination.prevPage(paramsPagination);
    onSelectPrev(e, {
      page: page
    });
  };

  var range = pagination.range(paramsPagination);
  var nextPage = pagination.nextPage(paramsPagination);
  var prevPage = pagination.prevPage(paramsPagination);
  var isHidePrev = hideDisabled && !prevPage;
  var isHideNext = hideDisabled && !nextPage;
  return React.createElement("div", {
    className: BASE_CLASS
  }, React.createElement(MoleculeButtonGroup, null, !isHidePrev && React.createElement(AtomButtom, {
    onClick: handleClickPrev,
    design: prevButtonDesign,
    disabled: !prevPage
  }, PrevButtonIcon && React.createElement("span", {
    className: CLASS_PREV_BUTTON_ICON
  }, React.createElement(PrevButtonIcon, null)), prevButtonText), compressed ? React.createElement(PageButton, {
    page: page,
    design: selectedPageButtonDesign,
    onSelectPage: onSelectPage
  }, page) : range.map(function (pageRange) {
    return React.createElement(PageButton, {
      key: pageRange,
      page: pageRange,
      design: pageRange === page ? selectedPageButtonDesign : nonSelectedPageButtonDesign,
      onSelectPage: onSelectPage
    }, pageRange);
  }), !isHideNext && React.createElement(AtomButtom, {
    onClick: handleClickNext,
    design: nextButtonDesign,
    disabled: !nextPage
  }, nextButtonText, NextButtonIcon && React.createElement("span", {
    className: CLASS_NEXT_BUTTON_ICON
  }, React.createElement(NextButtonIcon, null)))));
};

MoleculePagination.displayName = 'MoleculePagination';
MoleculePagination.defaultProps = {
  showPages: 10,
  compressed: false,
  prevButtonText: 'Previous',
  nextButtonText: 'Next',
  onSelectPrev: function onSelectPrev() {},
  onSelectNext: function onSelectNext() {},
  onSelectPage: function onSelectPage() {},
  selectedPageButtonDesign: 'solid',
  nonSelectedPageButtonDesign: 'flat',
  prevButtonDesign: 'flat',
  nextButtonDesign: 'flat'
};
export default MoleculePagination;